@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-__version_info__ = (1, 0, 5)
+__version_info__ = (1, 0, 6)
 __version__ = '.'.join(str(i) for i in __version_info__)
 
 import re
@@ -130,7 +130,7 @@ class Parser (object):
             else:
                 return value
             return '<span style="color:%(color)s;">%(value)s</span>' % {
-                'color': color,
+                'color': self._replace(color, self.REPLACE_ESCAPE),
                 'value': value,
             }
         self.add_formatter('color', _render_color)
@@ -138,7 +138,7 @@ class Parser (object):
             href = options['url'] if (options and 'url' in options) else value
             if '://' not in href:
                 href = 'http://' + href
-            return '<a href="%s">%s</a>' % (href, value)
+            return '<a href="%s">%s</a>' % (self._replace(href, self.REPLACE_ESCAPE), value)
         self.add_formatter('url', _render_url, replace_links=False, replace_cosmetic=False)
 
     def _replace(self, data, replacements):
@@ -196,7 +196,7 @@ class Parser (object):
                         in_quote = False
                         in_value = False
                         if attr:
-                            opts[attr] = value.strip()
+                            opts[attr.lower()] = value.strip()
                         attr = ''
                         value = ''
                     else:
@@ -206,7 +206,7 @@ class Parser (object):
                         in_quote = True
                     elif ch == ' ' and data.find('=', pos + 1) > 0:
                         # If there is no = after this, the value may accept spaces.
-                        opts[attr] = value.strip()
+                        opts[attr.lower()] = value.strip()
                         attr = ''
                         value = ''
                         in_value = False
@@ -225,15 +225,15 @@ class Parser (object):
                             if name is None:
                                 name = attr
                             else:
-                                opts[attr] = ''
+                                opts[attr.lower()] = ''
                         attr = ''
                         attr_done = False
                     attr += ch
         if attr:
             if name is None:
                 name = attr
-            opts[attr] = value.strip()
-        return name, opts
+            opts[attr.lower()] = value.strip()
+        return name.lower(), opts
 
     def _parse_tag(self, tag):
         """
